UAEPassWebViewResultModel class
Constructors
- UAEPassWebViewResultModel({required bool status, required String? message, UAEDataModel? uaeDataModel, int? statusCode = kOkResultCode})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ bool
-
getter/setter pair
- statusCode ↔ int?
-
getter/setter pair
- uaeDataModel ↔ UAEDataModel?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited